    processor 6502
    include vcs.h
    include macro.h
    include music.h

; Compile switches

NTSC                    = 0
PAL                     = 1 
COMPILE_VERSION         = NTSC

; Equates

BALLOONFRAMES           = 14
KERNEL_HEIGHT           = $9C
BALLOON_HEIGHT          = 19
PF_LINES                = 26
PF_SIZE                 = 3
VERTBOTTOMLIMIT         = BALLOON_HEIGHT
VERTTOPLIMIT            = KERNEL_HEIGHT
MAXTIMER                = $44
MAXLIVES                = 4

; Variables

    SEG.U vars
    ORG $80

verPosBalloon       ds 1
horPosBalloon       ds 1
frameCounter        ds 1
balloonAnim         ds 1
balloonPtr          ds 2
balloonmovPtr       ds 2
balloonOffset       ds 1
shiftval            ds 1
charPtr             ds 12
lines               ds 1
bcdScore            ds 3
tempVar1            ds 1
levelTimer          ds 1
lives               ds 1

    SEG     Bank0
    ORG $F000

;#######################
;# MAIN SCREEN DISPLAY #
;#######################

SkipBalloon
                LDA #$00
                SLEEP 7
                BEQ BalloonContinue
SkipBalloon2
                LDA #$00
                SLEEP 7
                BEQ BalloonContinue2

; Start display kernel
Maindisplay
        LDY shiftval
        LDX shifttab,Y
ShiftMore
        STA WSYNC
        STA VBLANK          ; Stop vertical blank
        DEX
        BPL ShiftMore

        JSR DrawScore

        LDA horPosBalloon
        LDX #$00
        JSR PosElement        

        LDA #$32           ;
        STA COLUP0         ; Sprite colour

        LDA #$FF
        STA PF1
        STA PF2
        STA HMCLR
        LDY #KERNEL_HEIGHT
        STA WSYNC
        STX PF1
        STX PF2
        LDX #PF_LINES-1
load    
        LDA #BALLOON_HEIGHT-1
        DCP balloonOffset
        BCC SkipBalloon
        LDA (balloonmovPtr),Y
        STA HMP0
        LDA (balloonPtr),Y
BalloonContinue
        STA WSYNC
        STA HMOVE
        STA GRP0
        LDX divideby3,Y
        LDA BALLOONLEVEL1_0,X
        STA PF1
        LDA BALLOONLEVEL1_1,X
        STA PF2
        DEY
        LDA #BALLOON_HEIGHT-1
        DCP balloonOffset

        SLEEP 8

        LDA BALLOONLEVEL1_2,X
        STA PF2
        LDA BALLOONLEVEL1_3,X
        STA PF1
        BCC SkipBalloon2
        LDA (balloonmovPtr),Y
        STA HMP0
        LDA (balloonPtr),Y
BalloonContinue2
        STA WSYNC
        STA HMOVE
        STA GRP0
        LDA #$00
        STA PF1
        STA PF2

        SLEEP 32

        DEY
        BNE  load      ;get ready for next scanline

        STA WSYNC
        STY GRP0

        LDA #$FF
        STA PF1
        STA PF2

        LDA levelTimer
        AND #$FC
        CLC
        ADC #$13
        STA tempVar1

; State display
        LDX lives
        LDA LIVESNUSIZ,X
        STA NUSIZ0
        LDA LIVESOFFSET,X
        SEC
        LDY #$00
        STA WSYNC                ;
        STY CTRLPF
        STY PF1
        STY PF2
.waitzone1
        SBC #$0F                 ;
        BCS .waitzone1            ; RESP loop
        EOR #$07                 ;
        ASL                      ;
        ASL                      ;
        ASL                      ;
        ASL                      ;
        STA HMP0
        STA RESP0

        LDA tempVar1
        STA WSYNC                ;
        SEC
.waitzone2
        SBC #$0F                 ;
        BCS .waitzone2
        EOR #$07                 ;
        ASL                      ;
        ASL                      ;
        ASL                      ;
        ASL                      ;
        STA HMP1
        STA RESP1
        STA WSYNC
        STA HMOVE

        LDA levelTimer
        LSR
        LSR
        LSR
        LSR
        TAX
        LDY TIMERCOLOR,X
        STY COLUPF
        STY COLUP1

        LDA levelTimer
        LSR
        LSR
        TAX
        LDA levelTimer
        AND #$03
        TAY
        LDA TIMERSHAPE,Y
        STA tempVar1

        LDY #$07
NextStateLine
        STA WSYNC
        LDA #$00
        STA GRP0
        LDA tempVar1
        STA GRP1
        LDA TIMERPF1,X
        STA PF1
        LDA TIMERPF2,X
        STA PF2
        LDA LIVESSHAPE,Y
        STA GRP0
        LDA #$00
        STA PF1
        STA HMP0
        STA HMP1
        SLEEP 2
        STA PF2
        DEY
        BPL NextStateLine
        INY
        STY WSYNC
        STY GRP1
        STY NUSIZ0
        STY GRP0
        STY GRP1
        INY
        STY CTRLPF

        LDA shiftval
        EOR #$08
        TAY
        LDX shifttab,Y
        INX
        INX
        INX
ShiftMore2
        STA WSYNC
        DEX
        BPL ShiftMore2

        LDX  #$1E
        JMP Overscan

;########################
;# CARTRIDGE MAIN ENTRY #
;########################

Start
    CLEAN_START
    JSR SetStartPos
    LDA #$01           ;
    STA CTRLPF

    SET_POINTER balloonPtr, BALLOON18
    SET_POINTER balloonmovPtr, BALLOONM

; Main Program Loop

NEWSCREEN
    VERTICAL_SYNC

; Set VBLANK timer
    IF COMPILE_VERSION = PAL
        LDA #73
    ELSE
        LDA #43
    ENDIF
    STA TIM64T

    LDX balloonAnim
    LDA #KERNEL_HEIGHT
    SEC
    SBC verPosBalloon
    ADC #BALLOON_HEIGHT-1
    STA balloonOffset
    CLC
    ADC balloonAnimTab,X
    STA balloonPtr
    LDA balloonOffset
    CLC
    ADC balloonMoveTab,X
    STA balloonmovPtr
    LDA balloonMoveTabHigh,X
    STA balloonmovPtr+1

; Prepare Scoredisplay
    LDA #%01011
    STA NUSIZ0
    STA NUSIZ1
    STA VDELP0
    STA VDELP1
    STA WSYNC
    LDX #7
.Wait
    DEX
    BNE .Wait
    STA.W RESP0
    STA RESP1
    LDA #$14
    STA HMP1
    LSR
    STA HMP0
    STA WSYNC
    STA HMOVE
    LDX #11
NextDigit
    TXA
    LSR
    LSR
    TAY
    LDA bcdScore,Y      ; load low/high values of states
    STA tempVar1
    AND #$0F            ; select lower nibble
    TAY                 ; X-> shape of value
    LDA #>zero          ; Load pointer to desired value
    STA charPtr,X       ; Store sprite pointer
    STA charPtr-2,X       ; Store sprite pointer
    DEX
    LDA digittab,Y      ; Load pointer to desired value
    STA charPtr,X       ; Store sprite pointer
    DEX
    DEX 
    LDA tempVar1         ; load low/high values of states
    LSR                 ; select higher nibble... 
    LSR                 ; ...of status value (bcd!)
    LSR                 ; (numbers 0-9)
    LSR                 ;
    TAY                 ; X-> shape of value
    LDA digittab,Y      ; Load pointer to desired value
    STA charPtr,X       ; Store sprite pointer
    DEX
    BPL NextDigit
    LDA #$06
    STA lines
    LDA #$0F
    STA COLUP0 
    STA COLUP1
    LDA #$AA
    STA COLUPF         ; Sprite colour

VBLANKLOOP
    LDA INTIM
    BNE VBLANKLOOP  ; WAIT FOR VBLANK TIMER
    JMP Maindisplay

Overscan

; Set Overscan timer
    IF COMPILE_VERSION = PAL
        LDA #65
    ELSE
        LDA #36
    ENDIF
    STA TIM64T

; Collission Detection
    LDA CXP0FB
    ASL
    BCC NoCol
    JSR SetStartPos
NoCol    
    STA CXCLR

; Frame Stuff
    INC frameCounter
    LDA frameCounter
    AND #$01
    BNE NoJoy
    JSR joy        ;overscan. Time to read the joysticks.
NoJoy

    LDA #$01
    JSR AddScore

    LDA frameCounter
    LSR
    LSR
    LSR
    LSR
    AND #$0F
    CMP shiftval
    BEQ NoChange
    STA shiftval
    TAX
    LDA shiftaddtab,X
    CLC
    ADC verPosBalloon
    STA verPosBalloon
NoChange
  
; Limit vertical movement
    LDA verPosBalloon
    CMP #VERTBOTTOMLIMIT
    BCS PosFine1
    LDA #VERTBOTTOMLIMIT
PosFine1
    CMP #VERTTOPLIMIT+1
    BCC PosFine2
    LDA #VERTTOPLIMIT
PosFine2
    STA verPosBalloon

    LDA frameCounter
    AND #$07
    BNE OVERSCANLOOP

    INC lives
    LDA lives
    EOR #MAXLIVES
    BNE LivesDone
    STA lives
LivesDone

    INC levelTimer
    LDA levelTimer
    EOR #MAXTIMER
    BNE LTDone
    STA levelTimer
LTDone


; Balloon Animation
    INC balloonAnim
    LDA balloonAnim
    EOR #BALLOONFRAMES
    BNE OVERSCANLOOP
    STA balloonAnim

OVERSCANLOOP
    LDA INTIM
    BNE OVERSCANLOOP    ; WAIT FOR OVERSCAN TIMER
    STA WSYNC       ; FINISH WAITING FOR THE CURRENT LINE

    JMP NEWSCREEN

joy     
        LDA SWCHA      
        ASL
        BCS RightDone
        INC horPosBalloon
RightDone
        ASL
        BCS LeftDone
        DEC horPosBalloon
LeftDone
        ASL
        BCS DownDone
        DEC verPosBalloon
DownDone
        ASL
        BCS UpDone
        INC verPosBalloon
UpDone
        RTS

AddScore
    SED
    CLC
    ADC bcdScore+2
    STA bcdScore+2
    LDA bcdScore+1
    ADC #$00
    STA bcdScore+1
    LDA bcdScore
    ADC #$00
    STA bcdScore
    CLD
    RTS

    ORG $FA00

divideby3
    .byte 0,0
    .byte 0,0,0
    .byte 0,0,0
    .byte 1,1,1
    .byte 1,1,1
    .byte 2,2,2
    .byte 2,2,2
    .byte 3,3,3
    .byte 3,3,3
    .byte 4,4,4
    .byte 4,4,4
    .byte 5,5,5
    .byte 5,5,5
    .byte 6,6,6
    .byte 6,6,6
    .byte 7,7,7
    .byte 7,7,7
    .byte 8,8,8
    .byte 8,8,8
    .byte 9,9,9
    .byte 9,9,9
    .byte 10,10,10
    .byte 10,10,10
    .byte 11,11,11
    .byte 11,11,11
    .byte 12,12,12
    .byte 12,12,12
    .byte 13,13,13
    .byte 13,13,13
    .byte 14,14,14
    .byte 14,14,14
    .byte 15,15,15
    .byte 15,15,15
    .byte 16,16,16
    .byte 16,16,16
    .byte 17,17,17
    .byte 17,17,17
    .byte 18,18,18
    .byte 18,18,18
    .byte 19,19,19
    .byte 19,19,19
    .byte 20,20,20
    .byte 20,20,20
    .byte 21,21,21
    .byte 21,21,21
    .byte 22,22,22
    .byte 22,22,22
    .byte 23,23,23
    .byte 23,23,23
    .byte 24,24,24
    .byte 24,24,24
    .byte 25,25,25
    .byte 25,25

    ORG $FB00
BALLOONLEVEL1_0
                                .byte   %11111111
                                .byte   %11111111
                                .byte   %11111110
                                .byte   %11111000
                                .byte   %11110000
                                .byte   %11110000
                                .byte   %11110000
                                .byte   %11110000
                                .byte   %11110000
                                .byte   %11110000
                                .byte   %11110000
                                .byte   %11110000
                                .byte   %11111000
                                .byte   %11111000
                                .byte   %11110000
                                .byte   %11110000
                                .byte   %11110000
                                .byte   %11111100
                                .byte   %11111111
                                .byte   %11111111
                                .byte   %11111111
                                .byte   %11100000
                                .byte   %11100000
                                .byte   %11100000
                                .byte   %11100000
                                .byte   %11100000

BALLOONLEVEL1_1
                                .byte   %11111111
                                .byte   %00000111
                                .byte   %00000000
                                .byte   %00000000
                                .byte   %00000000
                                .byte   %00000000
                                .byte   %00001100
                                .byte   %11111100
                                .byte   %11100000
                                .byte   %00000000
                                .byte   %00000000
                                .byte   %00000000
                                .byte   %00000000
                                .byte   %10000001
                                .byte   %11000011
                                .byte   %01111100
                                .byte   %00111000
                                .byte   %00010000
                                .byte   %00000001
                                .byte   %00000001
                                .byte   %00000011
                                .byte   %00000000
                                .byte   %11000000
                                .byte   %11000000
                                .byte   %11100000
                                .byte   %11111000

BALLOONLEVEL1_2
                                .byte   %10000000
                                .byte   %00000000
                                .byte   %00000000
                                .byte   %00000000
                                .byte   %00000000
                                .byte   %00000111
                                .byte   %00011111
                                .byte   %11111110
                                .byte   %11111100
                                .byte   %00011000
                                .byte   %00000000
                                .byte   %00000000
                                .byte   %00000000
                                .byte   %00000000
                                .byte   %00000010
                                .byte   %00111100
                                .byte   %00111100
                                .byte   %00001100
                                .byte   %00000100
                                .byte   %00000010
                                .byte   %00000000
                                .byte   %10000000
                                .byte   %11000000
                                .byte   %11000000
                                .byte   %11111100
                                .byte   %11111111

BALLOONLEVEL1_3
                                .byte   %11100000
                                .byte   %11100000
                                .byte   %11100000
                                .byte   %11100000
                                .byte   %11100000
                                .byte   %11111111
                                .byte   %11111111
                                .byte   %11111110
                                .byte   %11111100
                                .byte   %11111100
                                .byte   %11111000
                                .byte   %11110000
                                .byte   %11110000
                                .byte   %11110000
                                .byte   %11110000
                                .byte   %11111000
                                .byte   %11111000
                                .byte   %11110000
                                .byte   %11110000
                                .byte   %11110000
                                .byte   %11110000
                                .byte   %11110000
                                .byte   %11110000
                                .byte   %11111000
                                .byte   %11111110
                                .byte   %11111111

    ORG $FC00

PosElement
       SEC
       STA WSYNC                ;
.waitzone
       SBC #$0F                 ;
       BCS .waitzone            ; RESP loop
       EOR #$07                 ;
       ASL                      ;
       ASL                      ;
       ASL                      ;
       ASL                      ;
       STA HMP0,X
       STA RESP0,X           ; Position it!
       STA WSYNC
       STA HMOVE
       RTS                      ; done, that's all!

SetStartPos
    LDA #$14
    STA verPosBalloon
    LDA #$78
    STA horPosBalloon
    RTS

DrawScore
; slightly modified 48 pixel version:
loop2
    LDY lines           ;+3  63  189
    SLEEP 4
    lda     (charPtr),y     ;+5  68  204
    sta     WSYNC           ;go
    sta.w   GRP0            ;+3  71  213      D1     --      --     --
    lda     (charPtr+$2),y  ;+5   5   15
    sta     GRP1            ;+3   8   24      D1     D1      D2     --
    lda     (charPtr+$4),y  ;+5  13   39
    sta     GRP0            ;+3  16   48      D3     D1      D2     D2
    lda     (charPtr+$6),y  ;+5  21   63
    sta     tempVar1         ;+3  24   72
    LAX     (charPtr+$8),y  ;+5  29   87
    lda     (charPtr+$A),y  ;+5  36  108
    ldy     tempVar1         ;+3  41  123              !
    sty     GRP1            ;+3  44  132      D3     D3      D4     D2!
    stx     GRP0            ;+3  47  141      D5     D3!     D4     D4
    sta     GRP1            ;+3  50  150      D5     D5      D6     D4!
    sta     GRP0            ;+3  53  159      D4*    D5!     D6     D6
    dec     lines           ;+5  58  174                             !
    bpl     loop2           ;+2  60  180
    ldy #0
    sty GRP0
    sty GRP1
    sty GRP0
    sty NUSIZ0
    sty NUSIZ1
    sty VDELP0
    sty VDELP1
    rts

zero
    .byte %00111000
    .byte %01000100
    .byte %01000100
    .byte %01000100
    .byte %01000100
    .byte %01000100
    .byte %00111000

one
    .byte %00111000
    .byte %00010000
    .byte %00010000
    .byte %00010000
    .byte %00010000
    .byte %00110000
    .byte %00010000
    
two
    .byte %01111100
    .byte %01000000
    .byte %00100000
    .byte %00011000
    .byte %00000100
    .byte %01000100
    .byte %00111000

three
    .byte %00111000
    .byte %01000100
    .byte %00000100
    .byte %00011000
    .byte %00001000
    .byte %00000100
    .byte %01111100

four
    .byte %00001000
    .byte %00001000
    .byte %01111100
    .byte %01001000
    .byte %00101000
    .byte %00011000
    .byte %00001000

five
    .byte %00111000
    .byte %01000100
    .byte %00000100
    .byte %00000100
    .byte %01111000
    .byte %01000000
    .byte %01111100

six
    .byte %00111000
    .byte %01000100
    .byte %01000100
    .byte %01111000
    .byte %01000000
    .byte %00100000
    .byte %00011100

seven
    .byte %00010000
    .byte %00010000
    .byte %00010000
    .byte %00010000
    .byte %00001000
    .byte %00000100
    .byte %01111100

eight
    .byte %00111000
    .byte %01000100
    .byte %01000100
    .byte %00111000
    .byte %01000100
    .byte %01000100
    .byte %00111000

nine
    .byte %01110000
    .byte %00001000
    .byte %00000100
    .byte %00111100
    .byte %01000100
    .byte %01000100
    .byte %00111000

    ORG $FD90

BALLOONLLL
    .byte $00
    .byte $00
    .byte $F0
    .byte $F0
    .byte $F0
    .byte $F0
    .byte $F0
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $50
    .byte $00

BALLOONLL
    .byte $00
    .byte $00
    .byte $F0
    .byte $00
    .byte $F0
    .byte $00
    .byte $F0
    .byte $00
    .byte $F0
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $40
    .byte $00

    ORG $FE90

BALLOONL
    .byte $00
    .byte $00
    .byte $00
    .byte $F0
    .byte $00
    .byte $00
    .byte $F0
    .byte $00
    .byte $00
    .byte $F0
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $30
    .byte $00

BALLOONM
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00

BALLOONR
    .byte $00
    .byte $00
    .byte $00
    .byte $10
    .byte $00
    .byte $00
    .byte $10
    .byte $00
    .byte $00
    .byte $10
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $D0
    .byte $00

BALLOONRR
    .byte $00
    .byte $00
    .byte $10
    .byte $00
    .byte $10
    .byte $00
    .byte $10
    .byte $00
    .byte $10
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $C0
    .byte $00

BALLOONRRR
    .byte $00
    .byte $00
    .byte $10
    .byte $10
    .byte $10
    .byte $10
    .byte $10
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $00
    .byte $B0
    .byte $00

shifttab
        .byte 0,1,2,3,4,5,6,7,8,7,6,5,4,3,2,1

shiftaddtab
        .byte -1,1,1,1,1,1,1,1,1,-1,-1,-1,-1,-1,-1,-1

digittab
    .byte #<zero,#<one,#<two,#<three,#<four
    .byte #<five,#<six,#<seven,#<eight,#<nine

TIMERPF1
    .byte $00,$80,$C0,$E0,$F0,$F8,$FC,$FE,$FF,$FF,$FF,$FF,$FF,$FF,$FF,$FF,$FF,$FF
TIMERPF2
    .byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$03,$07,$0F,$1F,$3F,$7F,$FF,$FF

LIVESOFFSET
    .byte $0,$76,$66,$56

TIMERCOLOR
    .byte $80,$80,$88,$8A,$8C,$8F
    
TIMERSHAPE
    .byte $00,$80,$C0,$E0

    ORG $FF80

balloonMoveTabHigh
    .byte >BALLOONLLL,>BALLOONLLL
    .byte >BALLOONLL,>BALLOONL
    .byte >BALLOONM,>BALLOONR
    .byte >BALLOONRR,>BALLOONRRR
    .byte >BALLOONRRR,>BALLOONRR
    .byte >BALLOONR,>BALLOONM
    .byte >BALLOONL,>BALLOONLL

balloonMoveTab
    .byte <BALLOONLLL - KERNEL_HEIGHT - 1, <BALLOONLLL - KERNEL_HEIGHT - 1
    .byte <BALLOONLL - KERNEL_HEIGHT - 1, <BALLOONL - KERNEL_HEIGHT - 1
    .byte <BALLOONM - KERNEL_HEIGHT - 1, <BALLOONR - KERNEL_HEIGHT - 1
    .byte <BALLOONRR - KERNEL_HEIGHT - 1, <BALLOONRRR - KERNEL_HEIGHT - 1
    .byte <BALLOONRRR - KERNEL_HEIGHT - 1, <BALLOONRR - KERNEL_HEIGHT - 1
    .byte <BALLOONR - KERNEL_HEIGHT - 1, <BALLOONM - KERNEL_HEIGHT - 1
    .byte <BALLOONL - KERNEL_HEIGHT - 1, <BALLOONLL - KERNEL_HEIGHT - 1

balloonAnimTab
    .byte <BALLOON14 - KERNEL_HEIGHT - 1, <BALLOON14 - KERNEL_HEIGHT - 1
    .byte <BALLOON16 - KERNEL_HEIGHT - 1, <BALLOON17 - KERNEL_HEIGHT - 1
    .byte <BALLOON18 - KERNEL_HEIGHT - 1, <BALLOON17 - KERNEL_HEIGHT - 1
    .byte <BALLOON16 - KERNEL_HEIGHT - 1, <BALLOON14 - KERNEL_HEIGHT - 1
    .byte <BALLOON14 - KERNEL_HEIGHT - 1, <BALLOON16 - KERNEL_HEIGHT - 1
    .byte <BALLOON17 - KERNEL_HEIGHT - 1, <BALLOON18 - KERNEL_HEIGHT - 1
    .byte <BALLOON17 - KERNEL_HEIGHT - 1, <BALLOON16 - KERNEL_HEIGHT - 1

BALLOON18
        .byte %00010000
        .byte %00111000
        .byte %00010000
        .byte %00010000
        .byte %00010000
        .byte %00010000
        .byte %00010000
        .byte %00010000
        .byte %00010000
        .byte %00010000
        .byte %00010000
        .byte %00010000
        .byte %00111000
        .byte %01111100
        .byte %01111100
        .byte %01111100
        .byte %01111100
        .byte %00111000
        .byte %00010000

BALLOON17
        .byte %00010000
        .byte %00111000
        .byte %00010000
        .byte %00010000
        .byte %00010000
        .byte %00010000
        .byte %00010000
        .byte %00010000
        .byte %00010000
        .byte %00010000
        .byte %00010000
        .byte %00111000
        .byte %01111100
        .byte %01111100
        .byte %01111100
        .byte %01111100
        .byte %00111000
        .byte %00010000
        .byte %00000000

BALLOON16
        .byte %00010000
        .byte %00111000
        .byte %00010000
        .byte %00010000
        .byte %00010000
        .byte %00010000
        .byte %00010000
        .byte %00010000
        .byte %00010000
        .byte %00010000
        .byte %00111000
        .byte %01111100
        .byte %01111100
        .byte %01111100
        .byte %01111100
        .byte %00111000
        .byte %00010000
        .byte %00000000
        .byte %00000000

BALLOON14
        .byte %00010000
        .byte %00111000
        .byte %00010000
        .byte %00010000
        .byte %00010000
        .byte %00010000
        .byte %00010000
LIVESSHAPE
        .byte %00010000
        .byte %00111000
        .byte %01111100
        .byte %01111100
        .byte %01111100
        .byte %01111100
        .byte %00111000
        .byte %00010000
        .byte %00000000
        .byte %00000000
        .byte %00000000
        .byte %00000000

LIVESNUSIZ
    .byte $00,$00,$01,$03

    ORG $FFFA
    .WORD Start
    .WORD Start
    .WORD Start